@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: German homepage translation
-# Copyright (C) 2004-2010 Carsten Gnörlich
+# Copyright (C) 2004-2012 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 #
@@ -12,9 +12,9 @@ require("../include/dvdisaster.php");
 begin_page();
 ?>
 
-<!--- Insert actual page content below --->
+<!-- Insert actual page content below -->
 
-<h3>Impressum</h3>
+<h3 class="top">Impressum</h3>
 
 Carsten Gnörlich <br>
 Beerenkamp 23 <br>
@@ -36,7 +36,7 @@ Das Impressum gilt für die Internetpräsenz unter den Domänen<br>
 <a href="http://dvdisaster.net">dvdisaster.net</a>, &nbsp;
 <a href="http://dvdisaster.org">dvdisaster.org</a>.
 
-<!--- do not change below --->
+<!-- do not change below -->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
