@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: German homepage translation
-# Copyright (C) 2004-2010 Carsten Gnörlich
+# Copyright (C) 2004-2012 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 #
@@ -22,7 +22,7 @@ news_item("28.10.2007", "Überarbeitung der Dokumentation", "
    Version 0.72 überarbeitet. Bitte haben Sie ein wenig Geduld; die neue Dokumentation
    wird hoffentlich hilfreicher als die alte sein, aber es wird ein paar Wochen dauern
    bis alle Lücken wieder gefüllt sind.
-"); # end of news_item
+", 1, "2007-10-28T00:00:00Z", "2007-10-28T00:00:00Z");
 
 if($news_flash == 0) 
    end_page();
