@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: German homepage dictionary
-# Copyright (C) 2004-2010 Carsten Gnörlich
+# Copyright (C) 2004-2012 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 
@@ -16,11 +16,15 @@ $trans_screen_shot="Bildschirmfoto";
 
 $trans_contents="Inhalt";
 $trans_news="Neuigkeiten";
+$trans_atom_title="Neues von dvdisaster";
 $trans_hosting="Diese Seiten liegen auf";
 
 $trans_fdl="Die unveränderte Wiedergabe und Verteilung dieses gesamten Textes in beliebiger Form ist gestattet, sofern dieser Hinweis erhalten bleibt.";
-$trans_copyright="Copyright 2004-2011 Carsten Gnörlich.";
-$trans_modified="Die Informationen in diesem Handbuch beziehen sich auf die Originalversion von dvdisaster und sind möglicherweise nicht zutreffend.";
+$trans_copyright="Copyright 2004-2012 Carsten Gnörlich.";
 
-$trans_old_version="Alte Dokumentation (V0.70)";
+$trans_sourcecode="Quellkode für alle Betriebssysteme:";
+$trans_signature="Digitale Unterschrift:";
+$trans_md5="MD5-Prüfsumme:";
+$trans_macbinary="Binärversion für Mac OS X 10.5 / x86:";
+$trans_winbinary="Binärversion für Windows:";
 ?>
\ No newline at end of file
