@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: English homepage dictionary
-# Copyright (C) 2004-2010 Carsten Gnörlich
+# Copyright (C) 2004-2012 Carsten Gnörlich
 #
 # UTF-8 trigger: äöüß 
 
@@ -16,11 +16,15 @@ $trans_screen_shot="Screen shot";
 
 $trans_contents="Contents";
 $trans_news="News";
+$trans_atom_title="dvdisaster news";
 $trans_hosting="Hosted by";
 
 $trans_fdl="Verbatim copying and distribution of this entire article is permitted in any medium, provided this notice is preserved.";
-$trans_copyright="Copyright 2004-2011 Carsten Gnörlich.";
-$trans_modified="Information in this handbook relates to the original version of dvdisaster and may not be applicable.";
+$trans_copyright="Copyright 2004-2012 Carsten Gnörlich.";
 
-$trans_old_version="Old documentation (V0.70)";
+$trans_sourcecode="Source code for all operating systems:";
+$trans_signature="Digital signature:";
+$trans_md5="MD5 checksum:";
+$trans_macbinary="Binary for Mac OS X 10.5 / x86:";
+$trans_winbinary="Binary for Windows:";
 ?>
\ No newline at end of file
