@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: Russian homepage dictionary
-# Copyright (C) 2007-2010 Igor Gorbounov
+# Copyright (C) 2007-2009 Igor Gorbounov
 #
 # UTF-8 trigger: äöüß 
 
@@ -16,11 +16,15 @@ $trans_screen_shot="Снимок с экрана";
 
 $trans_contents="Содержание";
 $trans_news="Новости";
+$trans_atom_title="dvdisaster news";
 $trans_hosting="Размещено на";
 
 $trans_fdl="Дословное копирование и распространение всей этой статьи разрешается на любом носителе, при условии, что это уведомление сохраняется.";
 $trans_copyright="Copyright 2007-2009 Igor Gorbounov.";
-$trans_modified="Информация в этом руководстве относится к первоначальной версии программы dvdisaster и не может быть применима.";
 
-$trans_old_version="Старая документация (V0.70)";
+$trans_sourcecode="Исходные тексты для всех операционных систем:";
+$trans_signature="Цифровая подпись:";
+$trans_md5="MD5 checksum:";
+$trans_macbinary="Двоичная версия для Mac OS X 10.5 / x86:";
+$trans_winbinary="Двоичная версия для Windows:";
 ?>
