@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: Russian homepage translation
-# Copyright (C) 2007-2010 Igor Gorbounov
+# Copyright (C) 2007-2012 Igor Gorbounov
 #
 # UTF-8 trigger: äöüß 
 #
@@ -12,9 +12,9 @@ require("../include/dvdisaster.php");
 begin_page();
 ?>
 
-<!--- Insert actual page content below --->
+<!-- Insert actual page content below -->
 
-<h3>Цифровая подпись</h3>
+<h3 class="top">Цифровая подпись</h3>
 
 Выложенные для скачивания пакеты dvdisaster снабжены цифровой подписью с помощью
 <a href="http://www.gnupg.org/gnupg.html">GnuPG</a>, поэтому вы можете проверить
@@ -23,19 +23,26 @@ begin_page();
 
 Подпись была сделана с помощью следующего <a href="../pubkey.asc">открытого ключа</a>:
 
-<a href="../pubkey.asc">
 <pre>
 pub   1024D/F5F6C46C 2003-08-22
       Key fingerprint = 12B3 1535 AF90 3ADE 9E73  BA7E 5A59 0EFE F5F6 C46C
 uid                  dvdisaster (pkg signing key #1)
 sub   1024g/091AD320 2003-08-22
-</pre></a>
+</pre>
 
-Пишите на <img src="../images/email.png" align="top"> и вы получите
+Пишите на <img src="../images/email.png" alt="email shown as png image" class="valigntt"> и вы получите
 отпечаток ключа непосредственно от разработчиков. 
 В тему письма вставьте строку "GPG finger print".
 
-<!--- do not change below --->
+<h3>MD5 checksum</h3>
+
+Contrary to the digital signature, MD5 checksums are cryptographically weak:
+It is possible to create a manipulated package which still has the same
+checksum as the original. However MD5 checksums are sufficient for a quick
+check whether the download has finished completely and without transmission
+errors.
+
+<!-- do not change below -->
 
 <?php
 # end_page() adds the footer line and closes the HTML properly.
