@@ -1,6 +1,6 @@
 <?php
 # dvdisaster: Russian homepage translation
-# Copyright (C) 2007-2010 Igor Gorbounov
+# Copyright (C) 2007-2012 Igor Gorbounov
 #
 # UTF-8 trigger: äöüß 
 #
@@ -21,7 +21,7 @@ news_item("28.10.2007", "Начата новая документация", "
    В настоящее время документация на dvdisaster перерабатывается для предстоящего
    выхода V0.72. Наберитесь терпения; возможно, новая документация будет более
    полезной, чем старая, но нам требуется несколько недель, чтобы все охватить.
-"); # end of news_item
+", 1, "2007-10-28T00:00:00Z", "2007-10-28T00:00:00Z");
 
 if($news_flash == 0) 
    end_page();
